import { UUIButtonElement } from '@umbraco-ui/uui-button/lib';
/**
 * @summary A button to trigger text content to be copied to the clipboard
 * @element uui-button-copy-text
 * @dependency uui-button
 * @dependency uui-icon
 * @fires {UUICopyTextEvent} copying - Fires before the content is about to copied to the clipboard and can be used to transform or modify the data before its added to the clipboard
 * @fires {UUICopyTextEvent} copied - Fires when the content is copied to the clipboard
 * @slot - Use to replace the default content of the copy icon
 */
export declare class UUIButtonCopyTextElement extends UUIButtonElement {
    #private;
    /**
     * Set a string you wish to copy to the clipboard
     * @type {string}
     * @default ''
     */
    text: string;
    /**
     * Copies the text content from another element by specifying the ID of the element
     * The ID of the element does not need to start with # like a CSS selector
     * If this property is set, the value property is ignored
     * @type {string}
     * @attr
     * @default ''
     * @example copy-from="element-id"
     */
    copyFrom: string;
    /**
     * The delay in milliseconds before the button returns to its default state after a successful copy
     * @type {number}
     * @attr
     * @default 250
     */
    animationStateDelay: number;
    constructor();
    disconnectedCallback(): void;
    protected renderLabel(): import("lit-html").TemplateResult<1>;
    static readonly styles: import("lit").CSSResult[];
}
declare global {
    interface HTMLElementTagNameMap {
        'uui-button-copy-text': UUIButtonCopyTextElement;
    }
}
